Contact us
===============================================================================

We at LINCC Frameworks pride ourselves on being a friendly bunch!

If you're encountering issues, have some gnarly dataset, have ideas for
making our products better, or pretty much anything else, reach out!

* Open an issue in our github repo for hipscat-import
    * https://github.com/astronomy-commons/hipscat-import/issues/new
* If you're on LSSTC slack, so are we! 
  `#lincc-frameworks-qa <https://lsstc.slack.com/archives/C062LG1AK1S>`_